package com.njcn.gather.tool.parsepqdif.service;

import com.fasterxml.jackson.databind.JsonNode;
import com.njcn.gather.tool.parsepqdif.pojo.param.CsPqdifPathParam;
import com.njcn.gather.tool.parsepqdif.pojo.param.PqdifParseResultSaveParam;
import com.njcn.gather.tool.parsepqdif.pojo.vo.CsPqdifPathDetailVO;
import com.njcn.gather.tool.parsepqdif.pojo.vo.CsPqdifPathVO;

import java.util.List;

/**
 * PQDIF 存储记录服务。
 */
public interface CsPqdifPathService {

    List<CsPqdifPathVO> listPqdifPaths(CsPqdifPathParam.ListParam param);

    JsonNode getPqdifParseMsg(String pqdifId);

    CsPqdifPathDetailVO getPqdifParseDetail(String pqdifId);

    boolean addPqdifPath(CsPqdifPathParam param);

    boolean updatePqdifPath(CsPqdifPathParam.UpdateParam param);

    boolean deletePqdifPath(List<String> ids);

    boolean savePqdifParseResult(String pqdifId, PqdifParseResultSaveParam param);
}
